Crate dont_use_this_grep

Crate dont_use_this_grep 

Minigrep

minigrep defines a series of functions to find a string within a specified file and a Config struct designed to handle command line args

Structs

Config

Functions

run
search
search_case_insensitive